@@ -10,3 +10,7 @@ logging.basicConfig(
 logging.Formatter.converter = gmtime
 
 LOGGER = logging.getLogger("Commons")
+
+
+def get_logger(name: str):
+    return logging.getLogger(name)
