@@ -2,7 +2,7 @@ from airflow_commons.logger import LOGGER
 
 from airflow_commons.internal.util.file_utils import read_sql
 
-from airflow_commons.internal.mysql.auth import get_db_engine
+from airflow_commons.internal.mysql.auth import get_session
 from airflow_commons.internal.mysql.core import upsert
 from airflow_commons.internal.mysql.core import update as update_util
 from airflow_commons.internal.mysql.query_utils import get_delete_sql
@@ -32,14 +32,14 @@ def write_to_mysql(
     :param table_name: database table name to write
     :return:
     """
-    engine = get_db_engine(username, password, host, db_name)
+    Session = get_session(username, password, host, db_name)
     chunks = [values[i : i + chunk_size] for i in range(0, len(values), chunk_size)]
     LOGGER.info(f"Chunk size is {chunk_size}.")
-    with engine.connect() as conn:
+    with Session.begin() as session:
         i = 0
         for chunk in chunks:
             i += 1
-            upsert(values=chunk, conn=conn, table_name=table_name)
+            upsert(values=chunk, session=session, table_name=table_name)
             LOGGER.info(f"Chunk {i} uploaded")
     LOGGER.info("Data uploaded to MySql.")
 
@@ -64,8 +64,8 @@ def delete(
     :param where_statement_file: relative location of where statement sql file
     :param where_statement_params: parameters of where statements
     """
-    engine = get_db_engine(username, password, host, db_name)
-    connection = engine.raw_connection()
+    Session = get_session(username, password, host, db_name)
+
     if where_statement_params is None:
         where_statement_params = dict()
     where_statement = read_sql(sql_file=where_statement_file, **where_statement_params)
@@ -73,11 +73,9 @@ def delete(
         table_name=table_name,
         where_statement=where_statement,
     )
-    cursor = connection.cursor()
-    cursor.execute(sql)
-    connection.commit()
-    connection.close()
-    LOGGER.info(f"The below sql statement is executed \n {sql}")
+    with Session.begin() as session:
+        session.execute(sql)
+        LOGGER.info(f"The below sql statement is executed \n {sql}")
 
 
 def select_all(
@@ -103,8 +101,7 @@ def select_all(
     :param return_type: parameter which determines return type
     :return: iterable ResultProxy object that stores results of the select query
     """
-    engine = get_db_engine(username, password, host, db_name)
-    connection = engine.raw_connection()
+    Session = get_session(username, password, host, db_name)
     if where_statement_params is None:
         where_statement_params = dict()
     where_statement = read_sql(sql_file=where_statement_file, **where_statement_params)
@@ -112,14 +109,11 @@ def select_all(
         table_name=table_name,
         where_statement=where_statement,
     )
-    if return_type == "dataframe":
-        result = pd.read_sql(sql, connection)
-    else:
-        cursor = connection.cursor()
-        cursor.execute(sql)
-        result = cursor.fetchall()
-        connection.commit()
-        connection.close()
+    with Session.begin() as session:
+        if return_type == "dataframe":
+            result = session.execute(sql).fetchall()
+        else:
+            result = pd.read_sql(sql, session.bind)
     LOGGER.info(f"The below sql statement is executed \n {sql}")
     LOGGER.info(f"Number of records retrieved = {str(len(result))}")
     return result
@@ -144,14 +138,13 @@ def select(
     :param host: database host
     :param db_name: database name
     :param table_name: database table name
-    :param column_name: column name from the table
+    :param column_names: column name from the table
     :param where_statement_params: relative location of where statement sql file
     :param where_statement_file: parameters of where statements
     :param return_type: parameter which determines return type
     :return: iterable ResultProxy object that stores results of the select query
     """
-    engine = get_db_engine(username, password, host, db_name)
-    connection = engine.raw_connection()
+    Session = get_session(username, password, host, db_name)
     if where_statement_params is None:
         where_statement_params = dict()
     where_statement = read_sql(sql_file=where_statement_file, **where_statement_params)
@@ -160,14 +153,12 @@ def select(
         column_names=column_names,
         where_statement=where_statement,
     )
-    if return_type == "dataframe":
-        result = pd.read_sql(sql, connection)
-    else:
-        cursor = connection.cursor()
-        cursor.execute(sql)
-        result = cursor.fetchall()
-        connection.commit()
-        connection.close()
+    with Session.begin() as session:
+        if return_type == "dataframe":
+            result = session.execute(sql).fetchall()
+        else:
+            result = pd.read_sql(sql, session.bind)
+
     LOGGER.info(f"The below sql statement is executed \n {sql}")
     LOGGER.info(f"Number of records retrieved = {str(len(result))}")
     return result
@@ -182,8 +173,7 @@ def get_row_count(
     where_statement_file: str = None,
     where_statement_params: dict = None,
 ):
-    engine = get_db_engine(username, password, host, db_name)
-    connection = engine.raw_connection()
+    Session = get_session(username, password, host, db_name)
 
     if where_statement_file is not None:
         if where_statement_params is None:
@@ -198,14 +188,11 @@ def get_row_count(
         table_name=table_name,
         where_statement=where_statement,
     )
-
-    LOGGER.info(f"The below sql statement will be executed: \n {sql}")
-    cursor = connection.cursor()
-    cursor.execute(sql)
-    row_count = cursor.fetchone()[0]
-    connection.commit()
-    connection.close()
-    LOGGER.info("The sql statement is executed successfully\n")
+    with Session.begin() as session:
+        LOGGER.info(f"The below sql statement will be executed: \n {sql}")
+        cursor = session.execute(sql)
+        row_count = cursor.fetchone()[0]
+        LOGGER.info("The sql statement is executed successfully\n")
     return row_count
 
 
@@ -229,9 +216,7 @@ def update(
     exp: [{"values": [{"column": "column_name", "value": value_to_be_updated}],
          "where": "id = 1234"}]
     """
-    engine = get_db_engine(username, password, host, db_name)
-    conn = engine.connect()
-
-    update_util(table_name, values, engine, conn)
+    session = get_session(username, password, host, db_name)
+    update_util(table_name, values, session)
 
     LOGGER.info("Data updated on MySql.")
